from zope.interface import Interface
# -*- Additional Imports Here -*-


class IPressKit(Interface):
    """Folder that holds press documents downloadable as a zip bundle."""

    # -*- schema definition goes here -*-



"""Definition of the Press Kit content type
"""

from zope.interface import implements

from Products.Archetypes import atapi
from Products.ATContentTypes.content import folder
from Products.ATContentTypes.content import schemata

# -*- Message Factory Imported Here -*-

from Products.pressKit.interfaces import IPressKit
from Products.pressKit.config import PROJECTNAME

PressKitSchema = folder.ATFolderSchema.copy() + atapi.Schema((

    # -*- Your Archetypes field definitions here ... -*-

))

# Set storage on fields copied from ATFolderSchema, making sure
# they work well with the python bridge properties.

PressKitSchema['title'].storage = atapi.AnnotationStorage()
PressKitSchema['description'].storage = atapi.AnnotationStorage()

schemata.finalizeATCTSchema(
    PressKitSchema,
    folderish=True,
    moveDiscussion=False
)


class PressKit(folder.ATFolder):
    """Folder that holds press documents downloadable as a zip bundle."""
    implements(IPressKit)

    meta_type = "PressKit"
    schema = PressKitSchema
    schema['relatedItems'].widget.visible['edit'] = 'visible'

    title = atapi.ATFieldProperty('title')
    description = atapi.ATFieldProperty('description')

    # -*- Your ATSchema to Python Property Bridges Here ... -*-

atapi.registerType(PressKit, PROJECTNAME)



import time
import string
from zope.component import getUtility
from Products.Five import BrowserView
from Products.CMFCore.utils import getToolByName

class PressKitView(BrowserView):
    """
    Generates and returns a zip file with the contents of the press kit
    """
        
        


import time
import string
import os
from zope.component import getUtility
from Products.Five import BrowserView
from Products.CMFCore.utils import getToolByName
import zipfile
import urllib

class DownloadZipView(BrowserView):
    def generate_zip(self):
        """
        Generates and returns a zip file with the contents of the press kit
        """
        #Get all the files and images on the presskit
        catalog = getToolByName(self.context, 'portal_catalog')
        files = catalog.searchResults(path = {'query' : '/'.join(self.context.getPhysicalPath()),
            'depth' : 1 },
            sort_on = 'getObjPositionInParent',
        ) 
        
        mimetype = 'application/zip'
        zipfilename="/var/tmp/%s.zip"%self.context.id
        
        archive = zipfile.ZipFile(zipfilename,"a")
        for f in files:
            obj = f.getObject()
            fileobject = obj.getFile().getBlob().open()
            filename = obj.id
            archive.writestr(filename, fileobject.read())
            
        archive.close()
        
        archivefile = open(zipfilename, "r")
        
        archiveraw = archivefile.read()
        archivefile.close()
        os.remove(zipfilename)
        
        self.request.response.setHeader('content-type', mimetype)
        self.request.response.setHeader('content-length', len(archiveraw))
        self.request.response.setHeader('Content-Disposition',
            ' attachment; filename=%s' % (urllib.quote(zipfilename.split("/")[-1:][0])))

        self.request.response.write(archiveraw)
        
        